==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Zařízení je zaneprázdněno</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Odeslat poslední video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Odeslat jedno nebo více vybraných videí</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Video najdete v příloze</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Vyberte jeden nebo více souborů</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Ohraničení</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Zařízení je zaneprázdněno</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Oblast</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zvětšení</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nenahrávat kurzor myši</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videostopa</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Přehrávač</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen minimalizován na začátku nahrávání</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Nahrávací čas</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Velikost v KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Velikost plochy nahrávání</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Nastavení fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otevřít umístění</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odpočet</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Přehrát poslední video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Odeslat video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Vybrat jedno nebo více zařízení</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuální snímky za sekundu</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Začít</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Domovská stránka</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Seznam kontaktů</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Podpora</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Vývojář</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Snímky</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Příspěvek</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program pro záznam</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Překlady</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Zdrojový kód</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Zobrazit v liště</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nová verze k dispozici</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokodek</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Vybrat webkameru</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Zařízení je zaneprázdněno</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Odeslat poslední video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Odeslat jedno nebo více vybraných videí</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Video najdete v příloze</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Vyberte jeden nebo více souborů</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Ohraničení</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Zařízení je zaneprázdněno</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Oblast</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zvětšení</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nenahrávat kurzor myši</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videostopa</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Přehrávač</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen minimalizován na začátku nahrávání</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Nahrávací čas</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Velikost v KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Velikost plochy nahrávání</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Nastavení fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otevřít umístění</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odpočet</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Přehrát poslední video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Odeslat video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Vybrat jedno nebo více zařízení</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuální snímky za sekundu</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Začít</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Domovská stránka</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Podpora</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Vývojář</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Snímky</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Příspěvek</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program pro záznam</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Překlady</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Zdrojový kód</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Zobrazit v liště</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nová verze k dispozici</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokodek</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Vybrat webkameru</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
